@@ -5,3 +5,5 @@ demo(color)
 demo(manipulate)
 demo(awsimage)
 demo(awspimage)
+demo(combine)
+demo(segment)
\ No newline at end of file
